/*
File:   de Jong Box.c (DEJONGBX.C on MSDOS platforms)
Author: Eduard Schwan, CIS: 71513,2161
Descr:  Create the amazing de Jong box object,
        for the POV-Ray ray tracer.  Please see the
        accompanying documentation for more information.
Notes:  Compiled under Macintosh Metrowerks CW/4.  Should
        work with any ANSI C compiler.
History:
        06/1994   esp  Created from concept
        8/31/1994 esp  Cleaned up for distribution.
*/


#include <stdio.h>


/* Change this to the number of slices to create */
#define djbSize	 25


/* Print the header information for the include file */
void PrintdjHeader(int n)
{
	printf("// POV-Ray version 2 scene file\n");
	printf("// add you object here\n");
	printf("// #declare ObjectToSlice = object { ... }\n");
	printf("\n");
	printf("#declare djb_MaxRot = 20 // You can change this\n");
	printf("\n");
	printf("#declare djb_Object = object { ObjectToSlice }\n");
	printf("#declare djb_NSlices = %d // Don't touch!\n", n);
	printf("#declare djb_1NSlices = 1/djb_NSlices // Don't touch!\n");
	printf("\n");
	printf("#declare djb_Slice =\n");
	printf("box\n");
	printf("{\n");
	printf("  <-1.5,0,-1.5> <1.5,djb_1NSlices,1.5>\n");
	printf("  translate -0.5*y  scale <1,2,1> // move to bottom of cube\n");
	printf("}\n");
	printf("\n");
	printf("#declare djb_Bound =\n");
	printf("box\n");
	printf("{\n");
	printf("  <-1.51,-0.01,-1.51> <1.51,djb_1NSlices+0.01,1.51>\n");
	printf("  translate -0.5*y  scale <1,2,1> // move to bottom of cube\n");
	printf("}\n");
} /* PrintdjHeader */


/* write the whole box scene file, header and body, to stdout */
void PrintdjBox(int n)
{
	int k;

	PrintdjHeader(n);

	printf("#declare djBox = union\n");
	printf("{\n");

	for (k=0; k<n; k++)
	{
		printf("  intersection // slice %d of %d\n", k+1, n);
		printf("  {\n");
		printf("    object { djb_Object rotate %d/djb_NSlices*djb_MaxRot*y }\n",k);
		printf("    object { djb_Slice translate 2*%d/djb_NSlices*y }\n",k);
		printf("    bounded_by { djb_Bound translate 2*%d/djb_NSlices*y }\n",k);
		printf("  }\n");
	}

	printf("    bounded_by { box { -(x+y+z), x+y+z scale 1.01 } }\n",k);
	printf("} // union\n");
	printf("\n");
} /* PrintdjBox */



int main()
{
	PrintdjBox(djbSize);
	return 0;
} /* main */
